% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/plot.gg_minimal_depth.R
\name{plot.gg_minimal_depth}
\alias{plot.gg_minimal_depth}
\title{Plot a \code{\link{gg_minimal_depth}} object for random forest variable ranking.}
\usage{
\method{plot}{gg_minimal_depth}(x, selection = FALSE, type = c("named",
  "rank"), lbls, ...)
}
\arguments{
\item{x}{\code{\link{gg_minimal_depth}} object created from a \code{randomForestSRC::rfsrc} object}

\item{selection}{should we restrict the plot to only include variables selected by the
minimal depth criteria (boolean).}

\item{type}{select type of y axis labels c("named","rank")}

\item{lbls}{a vector of alternative variable names.}

\item{...}{optional arguments passed to \code{\link{gg_minimal_depth}}}
}
\value{
\code{ggplot} object
}
\description{
Plot a \code{\link{gg_minimal_depth}} object for random forest variable ranking.
}
\examples{
\dontrun{
#' ## Examples from RFSRC package...
## ------------------------------------------------------------
## classification example
## ------------------------------------------------------------
## You can build a randomForest
# iris_rf <- rfsrc(Species ~ ., data = iris)
# iris_vs <- var.select(iris_rf)
# ... or load a cached randomForestSRC object
data(iris_vs, package="ggRandomForests")

# Get a data.frame containing minimaldepth measures
gg_dta<- gg_minimal_depth(iris_vs)

# Plot the gg_mkinimal_depth object
plot(gg_dta)

## ------------------------------------------------------------
## Regression example
## ------------------------------------------------------------
# airq_rf <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
# airq_vs <- var.select(airq_rf)
# ... or load a cached randomForestSRC object
data(airq_vs, package="ggRandomForests")

# Get a data.frame containing error rates
gg_dta<- gg_minimal_depth(airq_vs)

# Plot the gg_error object
plot(gg_dta)

## ------------------------------------------------------------
## Survival example
## ------------------------------------------------------------
## veteran data
## randomized trial of two treatment regimens for lung cancer
# data(veteran, package = "randomForestSRC")
# veteran_rf <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
# veteran_vs <- var.select(veteran_rf)
# Load a cached randomForestSRC object
data(veteran_vs, package="ggRandomForests")

gg_dta <- gg_minimal_depth(veteran_vs)
plot(gg_dta)

}
}
\references{
Breiman L. (2001). Random forests, Machine Learning, 45:5-32.

Ishwaran H. and Kogalur U.B. (2007). Random survival forests for R,
Rnews, 7(2):25-31.

Ishwaran H. and Kogalur U.B. (2014). Random Forests for Survival,
Regression and Classification (RF-SRC), R package version 1.5.
}
\seealso{
\code{randomForestSRC::var.select} \code{\link{gg_minimal_depth}}
}

